=======
Credits
=======

Maintainers
-----------
* shervinabd92, NINDS, NIH <shervin.abdollahi@nih.gov>
* Inati Lab, NINDS, NIH <sara.inati@nih.gov>

Contributors
------------

* Souheil Inati, Inati Analytics <souheil.inati@gmail.com>
